/*Copyright (C) 2010-2012 Duncan Deveaux

This file is part of Hikou no mizu.

Hikou no mizu is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Hikou no mizu is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Hikou no mizu.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DEF_PHYSICS_ENGINE
#define DEF_PHYSICS_ENGINE

#include <vector>
#include "Structs/Vector.hpp"
#include "Structs/Box.hpp"

#include "PhysicsRoutines.hpp"

//Class managing physics by applying forces, testing collisions, ...
class PhysicsEngine
{
    public:
        PhysicsEngine();
        PhysicsEngine(const Box &physicsWorld, float gravity, float airFriction);
        
        void addObject(PhysicsObject *object);
        void removeObject(PhysicsObject *object);
        
        void update(float frameTime);
        
        void moveObjectX(PhysicsObject *objectToMove, float distance);
        void moveObjectY(PhysicsObject *objectToMove, float distance);
        void pulseObject(PhysicsObject *objectToPulse, float xForce, float yForce);
        
        std::vector<PhysicsObject*> objectHitTest(PhysicsObject *objectToTest);
        std::vector<PhysicsObject*> objectHitTest(PhysicsObject *objectToTest, const Box &patchedSize);
        
        bool worldHitTest(PhysicsObject *objectToTest);
        bool isOnGround(PhysicsObject *objectToTest);
        
        void setPhysicsWorld(const Box &physicsWorld);
        const Box &getPhysicsWorld() const;
        
        void setGravityForce(float gravity);
        float getGravityForce() const;
        
        void setAirFriction(float airFriction);
        float getAirFriction() const;
    
    private:
        std::vector< std::pair<PhysicsObject*, Vector> > m_physicsObjectsList;
        
        Box m_physicsWorld; //Physics world box
        float m_gravity; //Gravity force in pixels / second
        float m_airFriction; //Air friction in pixels / second
};

#endif
